All of lore.kernel.org
 help / color / mirror / Atom feed
From: Kay Sievers <kay.sievers@vrfy.org>
To: linux-hotplug@vger.kernel.org
Subject: [PATCH] udev - small script optimization
Date: Tue, 13 Jan 2004 03:50:15 +0000	[thread overview]
Message-ID: <20040113035015.GA9989@vrfy.org> (raw)

[-- Attachment #1: Type: text/plain, Size: 594 bytes --]

Optimize the scripts reflecting the now more powerful rule logic,
cause we can combine all known fields now in any order:

  The ide-devfs.sh is only executed if the kernel name matches with 'hd*':

    BUS="ide", KERNEL="hd*", PROGRAM="/etc/udev/ide-devfs.sh %k %b %n", NAME="%k", SYMLINK="%1c %2c"

  The name_cdrom.pl is only executed for ide and scsi devices, but not for a partition.
  It exits with nonzero to skip the rule if the CD is not found:

    KERNEL="[hs]d[a-z]", PROGRAM="name_cdrom.pl %M %m", NAME="%1c", SYMLINK="cdrom"


I'm happy for today, this was my last patch. :)

Kay

[-- Attachment #2: 06-script-optimization.diff --]
[-- Type: text/plain, Size: 3023 bytes --]

diff -Nru a/extras/ide-devfs.sh b/extras/ide-devfs.sh
--- a/extras/ide-devfs.sh	Tue Jan 13 04:38:46 2004
+++ b/extras/ide-devfs.sh	Tue Jan 13 04:38:46 2004
@@ -2,7 +2,7 @@
 
 # udev external PROGRAM script
 # return devfs-names for ide-devices
-# BUS="ide", PROGRAM="/etc/udev/ide-devfs.sh %k %b %n", RESULT="hd*", NAME="%1c", SYMLINK="%2c %3c"
+# BUS="ide", KERNEL="hd*", PROGRAM="/etc/udev/ide-devfs.sh %k %b %n", NAME="%k", SYMLINK="%1c %2c"
 
 HOST="${2%\.[0-9]}"
 TARGET="${2#[0-9]\.}"
@@ -38,10 +38,10 @@
 if [ -z "$3" ]; then
 	MEDIA=`cat /proc/ide/${1}/media`
 	if [ "${MEDIA}" = "cdrom" ]; then
-		echo $1 ide/host${HOST}/bus${BUS}/target${TARGET}/lun0/cd cdroms/cdrom`get_dev_number $1 cdrom`
+		echo ide/host${HOST}/bus${BUS}/target${TARGET}/lun0/cd cdroms/cdrom`get_dev_number $1 cdrom`
 	elif [ "${MEDIA}" = "disk" ]; then
-		echo $1 ide/host${HOST}/bus${BUS}/target${TARGET}/lun0/disc discs/disc`get_dev_number $1 disk`/disc
+		echo ide/host${HOST}/bus${BUS}/target${TARGET}/lun0/disc discs/disc`get_dev_number $1 disk`/disc
 	fi
 else
-	echo $1 ide/host${HOST}/bus${BUS}/target${TARGET}/lun0/part$3 discs/disc`get_dev_number $1 disk`/part$3
+	echo ide/host${HOST}/bus${BUS}/target${TARGET}/lun0/part$3 discs/disc`get_dev_number $1 disk`/part$3
 fi
diff -Nru a/extras/name_cdrom.pl b/extras/name_cdrom.pl
--- a/extras/name_cdrom.pl	Tue Jan 13 04:38:46 2004
+++ b/extras/name_cdrom.pl	Tue Jan 13 04:38:46 2004
@@ -2,19 +2,17 @@
 
 # a horribly funny script that shows how flexible udev can really be
 # This is to be executed by udev with the following rules:
-# BUS="ide", PROGRAM="name_cdrom.pl %M %m", PROGRAM="good*", NAME="%2c", SYMLINK="cdrom"
-# BUS="scsi", PROGRAM="name_cdrom.pl %M %m", PROGRAM="good*", NAME="%2c", SYMLINK="cdrom"
-#
-# The scsi rule catches USB cdroms and ide-scsi devices.
-#
+# KERNEL="[hs]d[a-z]", PROGRAM="name_cdrom.pl %M %m", NAME="%1c", SYMLINK="cdrom"
 
-use CDDB_get qw( get_cddb );
+use strict;
+use warnings;
 
-my %config;
+use CDDB_get qw( get_cddb );
 
-$dev_node = "/tmp/cd_foo";
+my $dev_node = "/tmp/cd_foo";
 
 # following variables just need to be declared if different from defaults
+my %config;
 $config{CDDB_HOST}="freedb.freedb.org";		# set cddb host
 $config{CDDB_PORT}=8880;			# set cddb port
 $config{CDDB_MODE}="cddb";			# set cddb mode: cddb or http
@@ -23,8 +21,8 @@
 # No user interaction, this is a automated script!
 $config{input}=0;
 
-$major = $ARGV[0];
-$minor = $ARGV[1];
+my $major = $ARGV[0];
+my $minor = $ARGV[1];
 
 # create our temp device node to read the cd info from
 unlink($dev_node);
@@ -38,11 +36,11 @@
 # remove the dev node we just created
 unlink($dev_node);
 
-# print out our cd name if we have found it
-unless(defined $cd{title}) {
-	print"bad unknown cdrom\n";
-} else {
+# print out our cd name if we have found it or skip rule by nonzero exit
+if (defined $cd{title}) {
 	$cd{artist} =~ s/ /_/g;
 	$cd{title} =~ s/ /_/g;
-	print "good $cd{artist}-$cd{title}\n";
+	print "$cd{artist}-$cd{title}\n";
+} else {
+	exit -1;
 }

             reply	other threads:[~2004-01-13  3:50 UTC|newest]

Thread overview: 3+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2004-01-13  3:50 Kay Sievers [this message]
2004-01-13 18:42 ` [PATCH] udev - small script optimization Greg KH
2004-01-13 19:27 ` Martin Hicks

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20040113035015.GA9989@vrfy.org \
    --to=kay.sievers@vrfy.org \
    --cc=linux-hotplug@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.